2023-08-21 Version: 1.0.2
- Generated python2 2020-05-12 for Sasti.

2023-07-24 Version: 1.0.1
- Add GetGraphQueryTemplates.
- Add Api GetGraphQueryResult.
- Support http.

2022-11-22 Version: 1.0.0
- Add DescribeDomainReport SDK.

